<?php

/*
 * Turns the odd $_FILES structure into something useful.
 *
 * This:
 * $_FILES = array(
 *  'name' => array(
 *    'parameter' => array('File1.txt', 'File2.jpg', ...)
 *  ),
 *  'type' => array(
 *    'parameter' => array('text/plain', 'image/jpeg', ...)
 *  )
 *  ...
 * );
 *
 * Becomes:
 * $_FILES = array(
 *   'parameter' => array(
 *     0 => array(
 *       'name' => 'File1.txt',
 *       'type' => 'text/plain',
 *       ...
 *     ),
 *     1 => array(
 *       'name' => 'File2.jpg',
 *       'type' => 'image/jpeg',
 *       ...
 *     )
 *     ...
 *   )
 * );
 */
function fixFilesArray($portion) {

  $values = array();
  $parameters = array_keys($portion['name']);
  
  foreach ($parameters as $parameter) {
  
    $values[$parameter] = array();
    
    for ($i = 0; $i < count($portion['name'][$parameter]); ++$i) {
    
      $values[$parameter][$i] = array(
        'name' => $portion['name'][$parameter][$i],
        'type' => $portion['type'][$parameter][$i],
        'size' => $portion['size'][$parameter][$i],
        'tmp_name' => $portion['tmp_name'][$parameter][$i],
        'error' => $portion['error'][$parameter][$i]
      );
    }
  }
  
  return $values;
}

?>